package com.sunmi.cloudprinterdemo.activity;

import android.support.v7.widget.DividerItemDecoration;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.PopupMenu;
import android.support.v7.widget.RecyclerView;
import android.view.Gravity;
import android.view.MenuItem;
import android.view.View;

import com.sunmi.cloudprinter.bean.PrinterDevice;
import com.sunmi.cloudprinterdemo.R;
import com.sunmi.cloudprinterdemo.adapter.BindPrinterAdapter;
import com.sunmi.cloudprinterdemo.base.BaseActivity;
import com.sunmi.cloudprinterdemo.rpc.HttpCallback;
import com.sunmi.cloudprinterdemo.rpc.IOTCloudApi;
import com.sunmi.cloudprinterdemo.utils.StatusBarUtils;

import org.androidannotations.annotations.AfterViews;
import org.androidannotations.annotations.EActivity;
import org.androidannotations.annotations.UiThread;
import org.androidannotations.annotations.ViewById;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.List;

@EActivity(R.layout.activity_main)
public class MainActivity extends BaseActivity {

    @ViewById(R.id.rv_printer)
    RecyclerView rvPrinter;

    private String shopId = "1";
    private List<PrinterDevice> printerDevices = new ArrayList<>();
    private BindPrinterAdapter adapter;

    @AfterViews
    void init() {
        StatusBarUtils.StatusBarLightMode(this);
        LinearLayoutManager layoutManager = new LinearLayoutManager(context);
        DividerItemDecoration decoration = new DividerItemDecoration(context, DividerItemDecoration.VERTICAL);
        rvPrinter.setLayoutManager(layoutManager);
        rvPrinter.addItemDecoration(decoration);
        IOTCloudApi.getPrinterList(shopId, new HttpCallback<String>(null) {
            @Override
            public void onSuccess(int code, String msg, String data) {
                try {
                    JSONArray jsonArray = new JSONArray(data);
                    for (int i = 0; i < jsonArray.length(); i++) {
                        JSONObject jsonObject = jsonArray.getJSONObject(i);
                        PrinterDevice device = new PrinterDevice();
                        if (jsonObject.has("msn")) {
                            device.setSn(jsonObject.getString("msn"));
                        }
                        if (jsonObject.has("is_online")) {
                            device.setStatus(Integer.parseInt(jsonObject.getString("is_online")));
                        }
                        printerDevices.add(device);
                        initAdapter();
                    }
                } catch (JSONException e) {
                    e.printStackTrace();
                }
            }
        });

    }

    @UiThread
    protected void initAdapter() {
        if (adapter == null) {
            adapter = new BindPrinterAdapter(context, printerDevices);
            adapter.setLongClickListener(new BindPrinterAdapter.OnLongClickListener() {
                @Override
                public void onLongClick(View view, String sn, int postion) {
                    PopupMenu menu = unbindMenu(view, sn, postion);
                    menu.show();
                }
            });
            rvPrinter.setAdapter(adapter);
        }
        adapter.notifyDataSetChanged();
    }

    private PopupMenu unbindMenu(View view, final String sn, final int position) {
        PopupMenu popupMenu = new PopupMenu(context, view);
        popupMenu.inflate(R.menu.menu_msg_detail);
        popupMenu.setGravity(Gravity.CENTER);
        popupMenu.setOnMenuItemClickListener(new PopupMenu.OnMenuItemClickListener() {
            @Override
            public boolean onMenuItemClick(MenuItem menuItem) {
                if (menuItem.getItemId() == R.id.unbind) {
                    IOTCloudApi.unbindPrinter(shopId, sn, new HttpCallback<String>(null) {
                        @Override
                        public void onSuccess(int code, String msg, String data) {
                            shortTip(R.string.str_unbind_success);
                            printerDevices.remove(position);
                            initAdapter();
                        }
                    });
                }
                return true;
            }
        });
        return popupMenu;
    }


    public void goToPrinter(View view) {
        StartConfigPrinterActivity_.intent(context).shopId(shopId).start();
    }
}
