package com.sunmi.cloudprinterdemo.adapter;

import android.content.Context;
import android.support.annotation.NonNull;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import com.sunmi.cloudprinter.bean.PrinterDevice;
import com.sunmi.cloudprinterdemo.R;
import com.sunmi.cloudprinterdemo.activity.PrinterManageActivity_;

import java.util.List;

/**
 * Description:
 *
 * @author linyuanpeng on 2019-09-17.
 */
public class BindPrinterAdapter extends RecyclerView.Adapter<BindPrinterAdapter.ViewHolder> {

    private Context context;
    private List<PrinterDevice> data;
    private OnLongClickListener longClickListener;

    public BindPrinterAdapter(Context context, List<PrinterDevice> data) {
        this.context = context;
        this.data = data;
    }

    public void setLongClickListener(OnLongClickListener longClickListener) {
        this.longClickListener = longClickListener;
    }

    @NonNull
    @Override
    public ViewHolder onCreateViewHolder(@NonNull ViewGroup viewGroup, int i) {
        View view = LayoutInflater.from(viewGroup.getContext())
                .inflate(R.layout.item_printer, viewGroup, false);
        return new ViewHolder(view);
    }

    @Override
    public void onBindViewHolder(@NonNull ViewHolder viewHolder, int i) {
        viewHolder.tvName.setText(data.get(i).getSn());
        showStatus(viewHolder, data.get(i));
    }

    private void showStatus(ViewHolder holder, PrinterDevice item) {
        if (item.getStatus() == 1) {
            holder.tvStatus.setText("在线");
            holder.ivStatus.setImageResource(R.mipmap.ic_device_status_normal);
        } else if (item.getStatus() == 0) {
            holder.tvStatus.setText("离线");
            holder.ivStatus.setImageResource(R.mipmap.ic_device_status_offline);
        } else {
            holder.tvStatus.setText("--");
        }
    }

    @Override
    public int getItemCount() {
        if (data.size() > 0) {
            return data.size();
        }
        return 0;
    }

    class ViewHolder extends RecyclerView.ViewHolder {

        TextView tvName;
        TextView tvStatus;
        ImageView ivStatus;

        ViewHolder(@NonNull View itemView) {
            super(itemView);
            tvName = itemView.findViewById(R.id.tv_name);
            tvStatus = itemView.findViewById(R.id.tv_status);
            ivStatus = itemView.findViewById(R.id.iv_status);
            itemView.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    PrinterManageActivity_.intent(context).shopId("1")
                            .sn(data.get(getAdapterPosition()).getSn())
                            .userId("1")
                            .channelId(1).start();
                }
            });
            itemView.setOnLongClickListener(new View.OnLongClickListener() {
                @Override
                public boolean onLongClick(View v) {
                    if (longClickListener != null) {
                        longClickListener.onLongClick(tvName, data.get(getAdapterPosition()).getSn(),
                                getAdapterPosition());
                    }
                    return false;
                }
            });
        }

    }

    public interface OnLongClickListener {
        void onLongClick(View view, String sn, int position);
    }
}
