package com.sunmi.cloudprinterdemo.rpc;

import android.util.Log;

import com.sunmi.cloudprinterdemo.config.PrinterConfig;
import com.sunmi.cloudprinterdemo.utils.DateTimeUtils;
import com.sunmi.cloudprinterdemo.utils.SecurityUtils;
import com.zhy.http.okhttp.callback.StringCallback;

import java.util.Iterator;
import java.util.Map;
import java.util.Set;
import java.util.SortedMap;
import java.util.TreeMap;


/**
 * Description: iot云接口
 * Created by Bruce on 2019/3/31.
 */
public class IOTCloudApi extends BaseHttpApi {

    private static final String BIND_PRINTER = PrinterConfig.IOT_CLOUD_URL + "v1/printer/printerAdd";//绑定打印机
    private static final String GET_PRINTER_LIST = PrinterConfig.IOT_CLOUD_URL + "v1/machine/queryBindMachine";//查询店铺下已绑定设备状态
    private static final String UNBIND_PRINTER = PrinterConfig.IOT_CLOUD_URL + "v1/printer/printerUnBind";//解绑打印机

    /**
     * 绑定打印机到iot云端
     *
     * @param sn 是	string	设备序列号
     */
    public static void bindPrinter(String shopId, String sn, StringCallback callback) {
        try {
            SortedMap<String, String> map = new TreeMap<>();
            String timeStamp = DateTimeUtils.currentTimeSecond() + "";
            map.put("app_id", PrinterConfig.APP_ID);
            map.put("timeStamp", timeStamp);
            map.put("shop_id", shopId);
            map.put("msn", sn);
            String sign = createSign(map);
            Log.e(TAG, "sign=" + sign);
            Log.e(TAG, "MD5=" + SecurityUtils.md5(sign));
            map.put("sign", SecurityUtils.md5(sign));
            post(BIND_PRINTER, map, callback);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 解绑
     *
     * @param sn 是	string	设备序列号
     */
    public static void unbindPrinter(String shopId, String sn, StringCallback callback) {

        try {
            SortedMap<String, String> map = new TreeMap<>();
            String timeStamp = DateTimeUtils.currentTimeSecond() + "";
            map.put("app_id", PrinterConfig.APP_ID);
            map.put("timeStamp", timeStamp);
            map.put("shop_id", shopId);
            map.put("msn", sn);
            map.put("sign", SecurityUtils.md5(createSign(map)));
            post(UNBIND_PRINTER, map, callback);
        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    /**
     * 绑定打印机到iot云端
     */
    public static void getPrinterList(String shopId, StringCallback callback) {
        try {
            SortedMap<String, String> map = new TreeMap<>();
            String timeStamp = DateTimeUtils.currentTimeSecond() + "";
            map.put("app_id", PrinterConfig.APP_ID);
            map.put("timeStamp", timeStamp);
            map.put("shop_id", shopId);
            map.put("sign", SecurityUtils.md5(createSign(map)));
            post(GET_PRINTER_LIST, map, callback);
        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    private static String createSign(SortedMap<String, String> map) {
        StringBuffer buffer = new StringBuffer();
        Set<Map.Entry<String, String>> entrySet = map.entrySet();
        Iterator<Map.Entry<String, String>> iterator = entrySet.iterator();
        while (iterator.hasNext()) {
            Map.Entry<String, String> entry = iterator.next();
            String key = entry.getKey();
            String value = entry.getValue();
            if (iterator.hasNext()) {
                buffer.append(key + "=" + value + "&");
            } else {
                buffer.append(key + "=" + value);
            }
        }
        buffer.append(PrinterConfig.APP_KEY);
        return buffer.toString();
    }
}
